use at4_protocol::messaging::ACControlMessage;
use at4_protocol::states;

fn main() {
    // Send this `message` to your AT4.
    let message = ACControlMessage::new(
        0,
        states::SetACPowerState::Maintain,
        states::SetACMode::Cool,
        Some(states::ACFanSpeed::Powerful),
        states::SetACSetpoint::Value(22),
    )
    .build();

    // Logic to send TCP packet
}
